@@ -7,7 +7,11 @@ from vessel.logging import logger
 
 class Payload(object):
   def __init__(self, token:str = None):
-    
+    if token:
+      if token.startswith("~"): # ~/.daas/TOKEN
+        token = token.split("/")[2]
+      if token.startswith("/"): # /home/rke/.daas/.daas/TOKEN
+        token = token.split("/")[4]
     self.token:str = token
     self.serviceaccount = []
     self.vault_ct = None
